@@ -78,7 +78,7 @@ impl FromStr for HashFn {
             "sha3-256" => Ok(Self::Sha3_256),
             #[cfg(feature = "sha3")]
             "sha3-512" => Ok(Self::Sha3_512),
-            _ => Err(format!("Unknown hash algorithm: {}", s)),
+            _ => Err(format!("Unknown hash algorithm: {s}")),
         }
     }
 }
@@ -409,8 +409,7 @@ impl FileHasher<'_> {
                 Ok(len_and_hash) => len_and_hash,
                 Err(e) => {
                     self.log.warn(format!(
-                        "Failed to load hash of file id = {} from the cache: {}",
-                        key, e
+                        "Failed to load hash of file id = {key} from the cache: {e}"
                     ));
                     None
                 }
@@ -431,8 +430,7 @@ impl FileHasher<'_> {
         {
             if let Err(e) = cache.put(key, metadata, data_len, hash) {
                 self.log.warn(format!(
-                    "Failed to store hash of file {} in the cache: {}",
-                    key, e
+                    "Failed to store hash of file {key} in the cache: {e}"
                 ))
             }
         };
@@ -444,7 +442,7 @@ fn format_output_stream(output: &str) -> String {
     if output.is_empty() {
         output
     } else {
-        format!("\n{}\n", output)
+        format!("\n{output}\n")
     }
 }
 
@@ -633,29 +631,19 @@ fn file_hash<H: StreamHasher>(
 #[cfg(test)]
 mod test {
     use metrohash::MetroHash128;
-    use std::fs::{create_dir_all, File};
     use std::io::Write;
-    use std::path::PathBuf;
+    use tempfile::NamedTempFile;
 
     use crate::file::{FileChunk, FileLen, FilePos};
     use crate::hasher::{file_hash, StreamHasher};
     use crate::path::Path;
 
     fn test_file_hash<H: StreamHasher>() {
-        let test_root = PathBuf::from("target/test/file_hash/");
-        create_dir_all(&test_root).unwrap();
+        let mut file1 = NamedTempFile::new().unwrap();
+        file1.write_all(b"Test file 1").unwrap();
 
-        let file1 = test_root.join("file1");
-        File::create(&file1)
-            .unwrap()
-            .write_all(b"Test file 1")
-            .unwrap();
-
-        let file2 = test_root.join("file2");
-        File::create(&file2)
-            .unwrap()
-            .write_all(b"Test file 2")
-            .unwrap();
+        let mut file2 = NamedTempFile::new().unwrap();
+        file2.write_all(b"Test file 2").unwrap();
 
         let file1 = Path::from(&file1);
         let file2 = Path::from(&file2);
